@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2005-01-05 22:48:37 +0100 (Mi, 05 Jan 2005) $
- * $LastChangedRevision: 785 $
+ * $LastChangedDate: 2005-07-01 20:21:31 +0200 (Fr, 01 Jul 2005) $
+ * $LastChangedRevision: 1007 $
  */
 
 #include <config.h>
@@ -39,8 +39,7 @@
 int prepare_download (void)
 {
   int ret = 0;
-  ret |= prepare_dir ("/var/cache/apt/archives");
-  ret |= prepare_dir ("/var/lib/apt/lists");
+  ret |= prepare_dir ("/var/cache/bootstrap");
   return ret != 0;
 }
 
